Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlibabacloudV1alpha1Client ¶
type AlibabacloudV1alpha1Client struct {
// contains filtered or unexported fields
}
AlibabacloudV1alpha1Client is used to interact with features provided by the alibabacloud.com group.
func New ¶
func New(c rest.Interface) *AlibabacloudV1alpha1Client
New creates a new AlibabacloudV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AlibabacloudV1alpha1Client, error)
NewForConfig creates a new AlibabacloudV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new AlibabacloudV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AlibabacloudV1alpha1Client
NewForConfigOrDie creates a new AlibabacloudV1alpha1Client for the given config and panics if there is an error in the config.
func (*AlibabacloudV1alpha1Client) ExternalSecrets ¶
func (c *AlibabacloudV1alpha1Client) ExternalSecrets(namespace string) ExternalSecretInterface
func (*AlibabacloudV1alpha1Client) RESTClient ¶
func (c *AlibabacloudV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*AlibabacloudV1alpha1Client) SecretStores ¶
func (c *AlibabacloudV1alpha1Client) SecretStores(namespace string) SecretStoreInterface
type AlibabacloudV1alpha1Interface ¶
type AlibabacloudV1alpha1Interface interface {
RESTClient() rest.Interface
ExternalSecretsGetter
SecretStoresGetter
}
type ExternalSecretExpansion ¶
type ExternalSecretExpansion interface{}
type ExternalSecretInterface ¶
type ExternalSecretInterface interface {
Create(ctx context.Context, externalSecret *v1alpha1.ExternalSecret, opts v1.CreateOptions) (*v1alpha1.ExternalSecret, error)
Update(ctx context.Context, externalSecret *v1alpha1.ExternalSecret, opts v1.UpdateOptions) (*v1alpha1.ExternalSecret, error)
UpdateStatus(ctx context.Context, externalSecret *v1alpha1.ExternalSecret, opts v1.UpdateOptions) (*v1alpha1.ExternalSecret, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.ExternalSecret, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.ExternalSecretList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.ExternalSecret, err error)
ExternalSecretExpansion
}
ExternalSecretInterface has methods to work with ExternalSecret resources.
type ExternalSecretsGetter ¶
type ExternalSecretsGetter interface {
ExternalSecrets(namespace string) ExternalSecretInterface
}
ExternalSecretsGetter has a method to return a ExternalSecretInterface. A group's client should implement this interface.
type SecretStoreExpansion ¶
type SecretStoreExpansion interface{}
type SecretStoreInterface ¶
type SecretStoreInterface interface {
Create(ctx context.Context, secretStore *v1alpha1.SecretStore, opts v1.CreateOptions) (*v1alpha1.SecretStore, error)
Update(ctx context.Context, secretStore *v1alpha1.SecretStore, opts v1.UpdateOptions) (*v1alpha1.SecretStore, error)
UpdateStatus(ctx context.Context, secretStore *v1alpha1.SecretStore, opts v1.UpdateOptions) (*v1alpha1.SecretStore, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.SecretStore, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.SecretStoreList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.SecretStore, err error)
SecretStoreExpansion
}
SecretStoreInterface has methods to work with SecretStore resources.
type SecretStoresGetter ¶
type SecretStoresGetter interface {
SecretStores(namespace string) SecretStoreInterface
}
SecretStoresGetter has a method to return a SecretStoreInterface. A group's client should implement this interface.