Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExternalSecretLister ¶
type ExternalSecretLister interface {
// List lists all ExternalSecrets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ExternalSecret, err error)
// ExternalSecrets returns an object that can list and get ExternalSecrets.
ExternalSecrets(namespace string) ExternalSecretNamespaceLister
ExternalSecretListerExpansion
}
ExternalSecretLister helps list ExternalSecrets. All objects returned here must be treated as read-only.
func NewExternalSecretLister ¶
func NewExternalSecretLister(indexer cache.Indexer) ExternalSecretLister
NewExternalSecretLister returns a new ExternalSecretLister.
type ExternalSecretListerExpansion ¶
type ExternalSecretListerExpansion interface{}
ExternalSecretListerExpansion allows custom methods to be added to ExternalSecretLister.
type ExternalSecretNamespaceLister ¶
type ExternalSecretNamespaceLister interface {
// List lists all ExternalSecrets in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ExternalSecret, err error)
// Get retrieves the ExternalSecret from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ExternalSecret, error)
ExternalSecretNamespaceListerExpansion
}
ExternalSecretNamespaceLister helps list and get ExternalSecrets. All objects returned here must be treated as read-only.
type ExternalSecretNamespaceListerExpansion ¶
type ExternalSecretNamespaceListerExpansion interface{}
ExternalSecretNamespaceListerExpansion allows custom methods to be added to ExternalSecretNamespaceLister.
type SecretStoreLister ¶
type SecretStoreLister interface {
// List lists all SecretStores in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SecretStore, err error)
// SecretStores returns an object that can list and get SecretStores.
SecretStores(namespace string) SecretStoreNamespaceLister
SecretStoreListerExpansion
}
SecretStoreLister helps list SecretStores. All objects returned here must be treated as read-only.
func NewSecretStoreLister ¶
func NewSecretStoreLister(indexer cache.Indexer) SecretStoreLister
NewSecretStoreLister returns a new SecretStoreLister.
type SecretStoreListerExpansion ¶
type SecretStoreListerExpansion interface{}
SecretStoreListerExpansion allows custom methods to be added to SecretStoreLister.
type SecretStoreNamespaceLister ¶
type SecretStoreNamespaceLister interface {
// List lists all SecretStores in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.SecretStore, err error)
// Get retrieves the SecretStore from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.SecretStore, error)
SecretStoreNamespaceListerExpansion
}
SecretStoreNamespaceLister helps list and get SecretStores. All objects returned here must be treated as read-only.
type SecretStoreNamespaceListerExpansion ¶
type SecretStoreNamespaceListerExpansion interface{}
SecretStoreNamespaceListerExpansion allows custom methods to be added to SecretStoreNamespaceLister.