v1alpha1

package
v0.0.0-...-f3c1a41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package v1alpha1 contains API Schema definitions for the alibabacloud v1alpha1 API group +k8s:deepcopy-gen=package,register +groupName=alibabacloud.com

Package alibabacloud contains alibabacloud API versions.

This file ensures Go source parsers acknowledge the alibabacloud package and any child packages. It can be removed if any other Go source files are added to this package.

Index

Constants

const (
	// SecretStoreReady indicates that the store is ready and able to serve requests.
	SecretStoreReady SecretStoreConditionType = "Ready"

	ReasonInvalidStore          = "InvalidStoreConfiguration"
	ReasonInvalidProviderConfig = "InvalidProviderConfig"
	ReasonValidationFailed      = "ValidationFailed"
	ReasonValidationUnknown     = "ValidationUnknown"
	ReasonStoreValid            = "Valid"
	ReasonClientCreationFailed  = "ClientCreationFailed"
	StoreUnmaintained           = "StoreUnmaintained"
)

These are valid conditions of a secret store.

Variables

var (
	// SchemeGroupVersion is group version used to register these objects
	SchemeGroupVersion = schema.GroupVersion{Group: "alibabacloud.com", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion}

	// AddToScheme is required by pkg/client/...
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type ClusterExternalSecret

type ClusterExternalSecret struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   ClusterExternalSecretSpec   `json:"spec,omitempty"`
	Status ClusterExternalSecretStatus `json:"status,omitempty"`
}

ClusterExternalSecret is the Schema for the clusterexternalsecrets API. +kubebuilder:object:root=true +kubebuilder:storageversion +kubebuilder:resource:scope=Cluster,categories={external-secrets},shortName=ces +kubebuilder:subresource:status +kubebuilder:metadata:labels="external-secrets.io/component=controller" +kubebuilder:printcolumn:name="Store",type=string,JSONPath=`.spec.externalSecretSpec.secretStoreRef.name` +kubebuilder:printcolumn:name="Refresh Interval",type=string,JSONPath=`.spec.refreshTime` +kubebuilder:printcolumn:name="Ready",type=string,JSONPath=`.status.conditions[?(@.type=="Ready")].status`

func (*ClusterExternalSecret) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecret.

func (*ClusterExternalSecret) DeepCopyInto

func (in *ClusterExternalSecret) DeepCopyInto(out *ClusterExternalSecret)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterExternalSecret) DeepCopyObject

func (in *ClusterExternalSecret) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterExternalSecretCondition

type ClusterExternalSecretCondition struct {
	// Choose namespace using a labelSelector
	// +optional
	NamespaceSelector *metav1.LabelSelector `json:"namespaceSelector,omitempty"`

	// Choose namespaces by name
	// +optional
	// +kubebuilder:validation:items:MinLength:=1
	// +kubebuilder:validation:items:MaxLength:=63
	// +kubebuilder:validation:items:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
	Namespaces []string `json:"namespaces,omitempty"`

	// Choose namespaces by using regex matching
	// +optional
	NamespaceRegexes []string `json:"namespaceRegexes,omitempty"`
}

ClusterExternalSecretCondition describes a condition by which to choose namespaces to process ExternalSecrets in for a ClusterExternalSecret instance.

func (*ClusterExternalSecretCondition) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretCondition.

func (*ClusterExternalSecretCondition) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterExternalSecretConditionType

type ClusterExternalSecretConditionType string

ClusterExternalSecretConditionType defines a value type for ClusterExternalSecret conditions.

const ClusterExternalSecretReady ClusterExternalSecretConditionType = "Ready"

ClusterExternalSecretReady is a ClusterExternalSecretConditionType set when the ClusterExternalSecret is ready.

type ClusterExternalSecretList

type ClusterExternalSecretList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ClusterExternalSecret `json:"items"`
}

ClusterExternalSecretList contains a list of ClusterExternalSecret.

func (*ClusterExternalSecretList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretList.

func (*ClusterExternalSecretList) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterExternalSecretList) DeepCopyObject

func (in *ClusterExternalSecretList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterExternalSecretNamespaceFailure

type ClusterExternalSecretNamespaceFailure struct {

	// Namespace is the namespace that failed when trying to apply an ExternalSecret
	Namespace string `json:"namespace"`

	// Reason is why the ExternalSecret failed to apply to the namespace
	// +optional
	Reason string `json:"reason,omitempty"`
}

ClusterExternalSecretNamespaceFailure represents a failed namespace deployment and it's reason.

func (*ClusterExternalSecretNamespaceFailure) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretNamespaceFailure.

func (*ClusterExternalSecretNamespaceFailure) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterExternalSecretSpec

type ClusterExternalSecretSpec struct {
	// The spec for the ExternalSecrets to be created
	ExternalSecretSpec ExternalSecretSpec `json:"externalSecretSpec"`

	// The name of the external secrets to be created.
	// Defaults to the name of the ClusterExternalSecret
	// +optional
	// +kubebuilder:validation:MinLength:=1
	// +kubebuilder:validation:MaxLength:=253
	// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$
	ExternalSecretName string `json:"externalSecretName,omitempty"`

	// The metadata of the external secrets to be created
	// +optional
	ExternalSecretMetadata ExternalSecretMetadata `json:"externalSecretMetadata,omitempty"`

	// A list of labels to select by to find the Namespaces to create the ExternalSecrets in. The selectors are ORed.
	// +optional
	// Deprecated : NamespaceSelectors field is deprecated, use Conditions field
	NamespaceSelectors []*metav1.LabelSelector `json:"namespaceSelectors,omitempty"`

	// A list of conditions to select by to find the Namespaces to create the ExternalSecrets in. The conditions are ORed.
	// +optional
	Conditions []ClusterExternalSecretCondition `json:"conditions,omitempty"`

	// The time in which the controller should reconcile its objects and recheck namespaces for labels.
	RotationInterval *metav1.Duration `json:"rotationInterval,omitempty"`
}

ClusterExternalSecretSpec defines the desired state of ClusterExternalSecret.

func (*ClusterExternalSecretSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretSpec.

func (*ClusterExternalSecretSpec) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterExternalSecretStatus

type ClusterExternalSecretStatus struct {
	// ExternalSecretName is the name of the ExternalSecrets created by the ClusterExternalSecret
	ExternalSecretName string `json:"externalSecretName,omitempty"`

	// Failed namespaces are the namespaces that failed to apply an ExternalSecret
	// +optional
	FailedNamespaces []ClusterExternalSecretNamespaceFailure `json:"failedNamespaces,omitempty"`

	// ProvisionedNamespaces are the namespaces where the ClusterExternalSecret has secrets
	// +optional
	ProvisionedNamespaces []string `json:"provisionedNamespaces,omitempty"`

	// +optional
	Conditions []ClusterExternalSecretStatusCondition `json:"conditions,omitempty"`
}

ClusterExternalSecretStatus defines the observed state of ClusterExternalSecret.

func (*ClusterExternalSecretStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretStatus.

func (*ClusterExternalSecretStatus) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterExternalSecretStatusCondition

type ClusterExternalSecretStatusCondition struct {
	Type               ClusterExternalSecretConditionType `json:"type"`
	Status             corev1.ConditionStatus             `json:"status"`
	LastTransitionTime metav1.Time                        `json:"lastTransitionTime,omitempty"`

	// +optional
	Message string `json:"message,omitempty"`
}

ClusterExternalSecretStatusCondition defines the observed state of a ClusterExternalSecret resource.

func (*ClusterExternalSecretStatusCondition) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterExternalSecretStatusCondition.

func (*ClusterExternalSecretStatusCondition) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterSecretStore

type ClusterSecretStore struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   ClusterSecretStoreSpec   `json:"spec,omitempty"`
	Status ClusterSecretStoreStatus `json:"status,omitempty"`
}

ClusterSecretStore represents a secure external location for storing secrets, which can be referenced as part of `storeRef` fields. +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:printcolumn:name="Status",type=string,JSONPath=`.status.conditions[?(@.type=="Ready")].reason` +kubebuilder:printcolumn:name="Capabilities",type=string,JSONPath=`.status.capabilities` +kubebuilder:printcolumn:name="Ready",type=string,JSONPath=`.status.conditions[?(@.type=="Ready")].status` +kubebuilder:subresource:status +kubebuilder:metadata:labels="external-secrets.io/component=controller" +kubebuilder:resource:scope=Cluster,categories={external-secrets},shortName=css

func (*ClusterSecretStore) DeepCopy

func (in *ClusterSecretStore) DeepCopy() *ClusterSecretStore

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSecretStore.

func (*ClusterSecretStore) DeepCopyInto

func (in *ClusterSecretStore) DeepCopyInto(out *ClusterSecretStore)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterSecretStore) DeepCopyObject

func (in *ClusterSecretStore) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterSecretStoreCondition

type ClusterSecretStoreCondition struct {
	// Choose namespace using a labelSelector
	// +optional
	NamespaceSelector *metav1.LabelSelector `json:"namespaceSelector,omitempty"`

	// Choose namespaces by name
	// +optional
	// +kubebuilder:validation:items:MinLength:=1
	// +kubebuilder:validation:items:MaxLength:=63
	// +kubebuilder:validation:items:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
	Namespaces []string `json:"namespaces,omitempty"`

	// Choose namespaces by using regex matching
	// +optional
	NamespaceRegexes []string `json:"namespaceRegexes,omitempty"`
}

ClusterSecretStoreCondition describes a condition by which to choose namespaces to process ExternalSecrets in for a ClusterSecretStore instance.

func (*ClusterSecretStoreCondition) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSecretStoreCondition.

func (*ClusterSecretStoreCondition) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterSecretStoreList

type ClusterSecretStoreList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ClusterSecretStore `json:"items"`
}

ClusterSecretStoreList contains a list of ClusterSecretStore resources.

func (*ClusterSecretStoreList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSecretStoreList.

func (*ClusterSecretStoreList) DeepCopyInto

func (in *ClusterSecretStoreList) DeepCopyInto(out *ClusterSecretStoreList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ClusterSecretStoreList) DeepCopyObject

func (in *ClusterSecretStoreList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ClusterSecretStoreSpec

type ClusterSecretStoreSpec struct {
	// INSERT ADDITIONAL SPEC FIELDS - desired state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	// maybe support more alibabacloud product
	KMS *KMSProvider `json:"KMS,omitempty"`
	OOS *OOSProvider `json:"OOS,omitempty"`

	// Used to constraint a ClusterSecretStore to specific namespaces. Relevant only to ClusterSecretStore
	// +optional
	Conditions []ClusterSecretStoreCondition `json:"conditions,omitempty"`
}

ClusterSecretStoreSpec defines the desired state of ClusterSecretStore +kubebuilder:validation:MinProperties=1

func (*ClusterSecretStoreSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSecretStoreSpec.

func (*ClusterSecretStoreSpec) DeepCopyInto

func (in *ClusterSecretStoreSpec) DeepCopyInto(out *ClusterSecretStoreSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ClusterSecretStoreStatus

type ClusterSecretStoreStatus struct {
	// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	// +optional
	Conditions []SecretStoreStatusCondition `json:"conditions,omitempty"`
	// +optional
	Capabilities SecretStoreCapabilities `json:"capabilities,omitempty"`
}

ClusterSecretStoreStatus defines the observed state of ClusterSecretStore

func (*ClusterSecretStoreStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSecretStoreStatus.

func (*ClusterSecretStoreStatus) DeepCopyInto

func (in *ClusterSecretStoreStatus) DeepCopyInto(out *ClusterSecretStoreStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type DataProcess

type DataProcess struct {
	Extract *DataSource `json:"extract,omitempty"`
	// +optional
	ReplaceKey []ReplaceRule `json:"replaceRule,omitempty"`
}

func (*DataProcess) DeepCopy

func (in *DataProcess) DeepCopy() *DataProcess

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataProcess.

func (*DataProcess) DeepCopyInto

func (in *DataProcess) DeepCopyInto(out *DataProcess)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type DataSource

type DataSource struct {
	SecretStoreRef *SecretStoreRef `json:"secretStoreRef,omitempty"`
	Key            string          `json:"key"`
	Name           string          `json:"name,omitempty"`
	VersionStage   string          `json:"versionStage,omitempty"`
	VersionId      string          `json:"versionId,omitempty"`
	//Optional array to specify what json key value pairs to extract from a secret and mount as individual secrets
	JMESPath    []JMESPathObject `json:"jmesPath,omitempty"`
	KmsEndpoint string           `json:"kmsEndpoint,omitempty"`
}

func (*DataSource) DeepCopy

func (in *DataSource) DeepCopy() *DataSource

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataSource.

func (*DataSource) DeepCopyInto

func (in *DataSource) DeepCopyInto(out *DataSource)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type DataSyncResult

type DataSyncResult struct {
	ExternalSecretKey   string      `json:"ExternalSecretKey,omitempty"`
	Status              string      `json:"status,omitempty"`
	Reason              string      `json:"reason,omitempty"`
	SynchronizationTime metav1.Time `json:"synchronizationTime,omitempty"`
}

func (*DataSyncResult) DeepCopy

func (in *DataSyncResult) DeepCopy() *DataSyncResult

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DataSyncResult.

func (*DataSyncResult) DeepCopyInto

func (in *DataSyncResult) DeepCopyInto(out *DataSyncResult)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecret

type ExternalSecret struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   ExternalSecretSpec   `json:"spec,omitempty"`
	Status ExternalSecretStatus `json:"status,omitempty"`
}

ExternalSecret is the Schema for the externalsecrets API +k8s:openapi-gen=true +kubebuilder:subresource:status +kubebuilder:resource:path=externalsecrets,scope=Namespaced

func (*ExternalSecret) DeepCopy

func (in *ExternalSecret) DeepCopy() *ExternalSecret

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecret.

func (*ExternalSecret) DeepCopyInto

func (in *ExternalSecret) DeepCopyInto(out *ExternalSecret)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ExternalSecret) DeepCopyObject

func (in *ExternalSecret) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ExternalSecretList

type ExternalSecretList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ExternalSecret `json:"items"`
}

ExternalSecretList contains a list of ExternalSecret

func (*ExternalSecretList) DeepCopy

func (in *ExternalSecretList) DeepCopy() *ExternalSecretList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretList.

func (*ExternalSecretList) DeepCopyInto

func (in *ExternalSecretList) DeepCopyInto(out *ExternalSecretList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ExternalSecretList) DeepCopyObject

func (in *ExternalSecretList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ExternalSecretMetadata

type ExternalSecretMetadata struct {
	// +optional
	Annotations map[string]string `json:"annotations,omitempty"`

	// +optional
	Labels map[string]string `json:"labels,omitempty"`
}

ExternalSecretMetadata defines metadata fields for the ExternalSecret generated by the ClusterExternalSecret.

func (*ExternalSecretMetadata) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretMetadata.

func (*ExternalSecretMetadata) DeepCopyInto

func (in *ExternalSecretMetadata) DeepCopyInto(out *ExternalSecretMetadata)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecretSpec

type ExternalSecretSpec struct {
	Provider    string        `json:"provider,omitempty"`
	Data        []DataSource  `json:"data,omitempty"`
	DataProcess []DataProcess `json:"dataProcess,omitempty"`
	Type        string        `json:"type,omitempty"`
	// Target defines how the secret is created in the cluster
	Target *ExternalSecretTarget `json:"target,omitempty"`
	// The time in which the controller should reconcile its objects and recheck namespaces for labels.
	RotationInterval *metav1.Duration `json:"rotationInterval,omitempty"`
}

ExternalSecretSpec defines the desired state of ExternalSecret +k8s:openapi-gen=true

func (*ExternalSecretSpec) DeepCopy

func (in *ExternalSecretSpec) DeepCopy() *ExternalSecretSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretSpec.

func (*ExternalSecretSpec) DeepCopyInto

func (in *ExternalSecretSpec) DeepCopyInto(out *ExternalSecretSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecretStatus

type ExternalSecretStatus struct {
	// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	DataSyncResults []DataSyncResult `json:"dataSyncResults,omitempty"`
}

ExternalSecretStatus defines the observed state of ExternalSecret

func (*ExternalSecretStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretStatus.

func (*ExternalSecretStatus) DeepCopyInto

func (in *ExternalSecretStatus) DeepCopyInto(out *ExternalSecretStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecretTarget

type ExternalSecretTarget struct {
	// Name defines the name of the secret resource to be managed.
	// If not set, the name will be auto-generated based on the ExternalSecret name.
	// +optional
	Name string `json:"name,omitempty"`

	// Template defines a template that can be used to generate or transform the secret data
	// +optional
	Template *ExternalSecretTemplate `json:"template,omitempty"`
}

ExternalSecretTarget defines the target secret

func (*ExternalSecretTarget) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretTarget.

func (*ExternalSecretTarget) DeepCopyInto

func (in *ExternalSecretTarget) DeepCopyInto(out *ExternalSecretTarget)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecretTemplate

type ExternalSecretTemplate struct {
	// Data defines the target secret's data field.
	// +optional
	Data map[string]string `json:"data,omitempty"`

	// TemplateFrom specifies sources for templates.
	// +optional
	TemplateFrom []TemplateFrom `json:"templateFrom,omitempty"`

	// Metadata defines the target secret's metadata fields.
	// +optional
	Metadata *ExternalSecretTemplateMetadata `json:"metadata,omitempty"`

	// Type defines the target secret's type field.
	// +optional
	Type corev1.SecretType `json:"type,omitempty"`

	// MergePolicy defines how template results should be merged with the original data.
	// Defaults to "Replace"
	// +optional
	// +kubebuilder:default="Replace"
	MergePolicy TemplateMergePolicy `json:"mergePolicy,omitempty"`
}

ExternalSecretTemplate defines the template for generating secret data

func (*ExternalSecretTemplate) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretTemplate.

func (*ExternalSecretTemplate) DeepCopyInto

func (in *ExternalSecretTemplate) DeepCopyInto(out *ExternalSecretTemplate)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ExternalSecretTemplateMetadata

type ExternalSecretTemplateMetadata struct {
	// Annotations to apply to the target secret.
	// +optional
	Annotations map[string]string `json:"annotations,omitempty"`
	// Labels to apply to the target secret.
	// +optional
	Labels map[string]string `json:"labels,omitempty"`
}

ExternalSecretTemplateMetadata defines the metadata for the generated secret

func (*ExternalSecretTemplateMetadata) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalSecretTemplateMetadata.

func (*ExternalSecretTemplateMetadata) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type JMESPathObject

type JMESPathObject struct {
	//JMES path to use for retrieval
	Path string `json:"path"`

	//File name in which to store the secret in.
	ObjectAlias string `json:"objectAlias"`
}

An individual json key value pair to mount

func (*JMESPathObject) DeepCopy

func (in *JMESPathObject) DeepCopy() *JMESPathObject

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JMESPathObject.

func (*JMESPathObject) DeepCopyInto

func (in *JMESPathObject) DeepCopyInto(out *JMESPathObject)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSAuth

type KMSAuth struct {
	// +optional
	AccessKey *SecretRef `json:"accessKey,omitempty"`
	// +optional
	AccessKeySecret          *SecretRef `json:"accessKeySecret,omitempty"`
	RAMRoleARN               string     `json:"ramRoleARN,omitempty"`
	RAMRoleSessionName       string     `json:"ramRoleSessionName,omitempty"`
	OIDCProviderARN          string     `json:"oidcProviderARN,omitempty"`
	OIDCTokenFilePath        string     `json:"oidcTokenFilePath,omitempty"`
	RoleSessionExpiration    string     `json:"roleSessionExpiration,omitempty"`
	RemoteRAMRoleARN         string     `json:"remoteRamRoleARN,omitempty"`
	RemoteRAMRoleSessionName string     `json:"remoteRamRoleSessionName,omitempty"`
	// +optional
	ServiceAccountRef *ServiceAccountRef `json:"serviceAccountRef,omitempty"`
}

func (*KMSAuth) DeepCopy

func (in *KMSAuth) DeepCopy() *KMSAuth

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSAuth.

func (*KMSAuth) DeepCopyInto

func (in *KMSAuth) DeepCopyInto(out *KMSAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KMSProvider

type KMSProvider struct {
	// +optional
	KMS *KMSAuth `json:"KMSAuth,omitempty"`
}

+kubebuilder:validation:MaxProperties=1

func (*KMSProvider) DeepCopy

func (in *KMSProvider) DeepCopy() *KMSProvider

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KMSProvider.

func (*KMSProvider) DeepCopyInto

func (in *KMSProvider) DeepCopyInto(out *KMSProvider)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type OOSAuth

type OOSAuth struct {
	// +optional
	AccessKey *SecretRef `json:"accessKey,omitempty"`
	// +optional
	AccessKeySecret          *SecretRef `json:"accessKeySecret,omitempty"`
	RAMRoleARN               string     `json:"ramRoleARN,omitempty"`
	RAMRoleSessionName       string     `json:"ramRoleSessionName,omitempty"`
	OIDCProviderARN          string     `json:"oidcProviderARN,omitempty"`
	OIDCTokenFilePath        string     `json:"oidcTokenFilePath,omitempty"`
	RoleSessionExpiration    string     `json:"roleSessionExpiration,omitempty"`
	RemoteRAMRoleARN         string     `json:"remoteRamRoleARN,omitempty"`
	RemoteRAMRoleSessionName string     `json:"remoteRamRoleSessionName,omitempty"`
	// +optional
	ServiceAccountRef *ServiceAccountRef `json:"serviceAccountRef,omitempty"`
}

func (*OOSAuth) DeepCopy

func (in *OOSAuth) DeepCopy() *OOSAuth

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OOSAuth.

func (*OOSAuth) DeepCopyInto

func (in *OOSAuth) DeepCopyInto(out *OOSAuth)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type OOSProvider

type OOSProvider struct {
	OOS *OOSAuth `json:"OOSAuth,omitempty"`
}

func (*OOSProvider) DeepCopy

func (in *OOSProvider) DeepCopy() *OOSProvider

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OOSProvider.

func (*OOSProvider) DeepCopyInto

func (in *OOSProvider) DeepCopyInto(out *OOSProvider)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ReplaceRule

type ReplaceRule struct {
	Target string `json:"target"`
	Source string `json:"source"`
}

func (*ReplaceRule) DeepCopy

func (in *ReplaceRule) DeepCopy() *ReplaceRule

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReplaceRule.

func (*ReplaceRule) DeepCopyInto

func (in *ReplaceRule) DeepCopyInto(out *ReplaceRule)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretRef

type SecretRef struct {
	Name string `json:"name"`
	// +optional
	// Namespace of the Secret.
	// For SecretStore, this field is ignored and the namespace of the SecretStore is used.
	// For ClusterSecretStore, this field is required to specify the namespace where the Secret exists.
	Namespace string `json:"namespace,omitempty"`
	Key       string `json:"key"`
}

SecretRef references a Secret resource. For SecretStore, this Secret must be in the same namespace as the SecretStore. For ClusterSecretStore, the Namespace field specifies which namespace the Secret exists in.

func (*SecretRef) DeepCopy

func (in *SecretRef) DeepCopy() *SecretRef

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretRef.

func (*SecretRef) DeepCopyInto

func (in *SecretRef) DeepCopyInto(out *SecretRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretStore

type SecretStore struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   SecretStoreSpec   `json:"spec,omitempty"`
	Status SecretStoreStatus `json:"status,omitempty"`
}

SecretStore is the Schema for the secretstores API

func (*SecretStore) DeepCopy

func (in *SecretStore) DeepCopy() *SecretStore

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStore.

func (*SecretStore) DeepCopyInto

func (in *SecretStore) DeepCopyInto(out *SecretStore)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*SecretStore) DeepCopyObject

func (in *SecretStore) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type SecretStoreCapabilities

type SecretStoreCapabilities string

SecretStoreCapabilities defines the possible operations a SecretStore can do.

const (
	// SecretStoreReadOnly indicates that the store can only read secrets.
	SecretStoreReadOnly SecretStoreCapabilities = "ReadOnly"
	// SecretStoreWriteOnly indicates that the store can only write secrets.
	SecretStoreWriteOnly SecretStoreCapabilities = "WriteOnly"
	// SecretStoreReadWrite indicates that the store can both read and write secrets.
	SecretStoreReadWrite SecretStoreCapabilities = "ReadWrite"
)

These are the valid capabilities of a secret store.

type SecretStoreConditionType

type SecretStoreConditionType string

SecretStoreConditionType represents the condition of the SecretStore.

type SecretStoreList

type SecretStoreList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []SecretStore `json:"items"`
}

SecretStoreList contains a list of SecretStore

func (*SecretStoreList) DeepCopy

func (in *SecretStoreList) DeepCopy() *SecretStoreList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStoreList.

func (*SecretStoreList) DeepCopyInto

func (in *SecretStoreList) DeepCopyInto(out *SecretStoreList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*SecretStoreList) DeepCopyObject

func (in *SecretStoreList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type SecretStoreRef

type SecretStoreRef struct {
	Name string `json:"name"`
	// Kind of the SecretStore resource (SecretStore or ClusterSecretStore)
	// Defaults to SecretStore
	// +optional
	// +kubebuilder:validation:Enum=SecretStore;ClusterSecretStore
	Kind string `json:"kind,omitempty"`
	// Deprecated : Namespace field is deprecated, use SecretStore in the same namespace as ExternalSecret, or use ClusterSecretStore
	// +optional
	Namespace string `json:"namespace"`
}

func (*SecretStoreRef) DeepCopy

func (in *SecretStoreRef) DeepCopy() *SecretStoreRef

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStoreRef.

func (*SecretStoreRef) DeepCopyInto

func (in *SecretStoreRef) DeepCopyInto(out *SecretStoreRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretStoreSpec

type SecretStoreSpec struct {
	// INSERT ADDITIONAL SPEC FIELDS - desired state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	// maybe support more alibabacloud product
	KMS *KMSProvider `json:"KMS,omitempty"`
	OOS *OOSProvider `json:"OOS,omitempty"`
}

+kubebuilder:validation:MinProperties=1 +kubebuilder:validation:MaxProperties=1

func (*SecretStoreSpec) DeepCopy

func (in *SecretStoreSpec) DeepCopy() *SecretStoreSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStoreSpec.

func (*SecretStoreSpec) DeepCopyInto

func (in *SecretStoreSpec) DeepCopyInto(out *SecretStoreSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretStoreStatus

type SecretStoreStatus struct {
	// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	// +optional
	Conditions []SecretStoreStatusCondition `json:"conditions,omitempty"`
	// +optional
	Capabilities SecretStoreCapabilities `json:"capabilities,omitempty"`
}

SecretStoreStatus defines the observed state of SecretStore

func (*SecretStoreStatus) DeepCopy

func (in *SecretStoreStatus) DeepCopy() *SecretStoreStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStoreStatus.

func (*SecretStoreStatus) DeepCopyInto

func (in *SecretStoreStatus) DeepCopyInto(out *SecretStoreStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type SecretStoreStatusCondition

type SecretStoreStatusCondition struct {
	Type   SecretStoreConditionType `json:"type"`
	Status corev1.ConditionStatus   `json:"status"`

	// +optional
	Reason string `json:"reason,omitempty"`

	// +optional
	Message string `json:"message,omitempty"`

	// +optional
	LastTransitionTime metav1.Time `json:"lastTransitionTime,omitempty"`

	// +optional
	ObservedGeneration int64 `json:"observedGeneration,omitempty"`
}

SecretStoreStatusCondition contains condition information for a SecretStore.

func (*SecretStoreStatusCondition) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretStoreStatusCondition.

func (*SecretStoreStatusCondition) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServiceAccountRef

type ServiceAccountRef struct {
	// Name of the ServiceAccount
	Name string `json:"name"`
	// +optional
	// Namespace of the ServiceAccount.
	// For SecretStore, this field is ignored and the namespace of the SecretStore is used.
	// For ClusterSecretStore, this field is required to specify the namespace where the ServiceAccount exists.
	Namespace string `json:"namespace,omitempty"`
	// +optional
	Audiences []string `json:"audiences,omitempty"`
}

ServiceAccountRef references a ServiceAccount resource. For SecretStore, it is in the same namespace as the SecretStore. For ClusterSecretStore, Namespace is required to specify the namespace of the ServiceAccount.

func (*ServiceAccountRef) DeepCopy

func (in *ServiceAccountRef) DeepCopy() *ServiceAccountRef

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceAccountRef.

func (*ServiceAccountRef) DeepCopyInto

func (in *ServiceAccountRef) DeepCopyInto(out *ServiceAccountRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TemplateFrom

type TemplateFrom struct {
	ConfigMap *TemplateRef `json:"configMap,omitempty"`
	Secret    *TemplateRef `json:"secret,omitempty"`

	// Target specifies where to place the template result.
	// For Secret resources, common values are: "Data", "Annotations", "Labels".
	// +optional
	// +kubebuilder:default="Data"
	Target TemplateTarget `json:"target,omitempty"`

	// +optional
	Literal *string `json:"literal,omitempty"`
}

TemplateFrom specifies a source for templates. Each item in the list can either reference a ConfigMap or a Secret resource.

func (*TemplateFrom) DeepCopy

func (in *TemplateFrom) DeepCopy() *TemplateFrom

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateFrom.

func (*TemplateFrom) DeepCopyInto

func (in *TemplateFrom) DeepCopyInto(out *TemplateFrom)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TemplateMergePolicy

type TemplateMergePolicy string

TemplateMergePolicy defines how template results should be merged with the original data. +kubebuilder:validation:Enum=Replace;Merge

const (
	// MergePolicyReplace replaces the entire template content during merge operations.
	MergePolicyReplace TemplateMergePolicy = "Replace"

	// MergePolicyMerge merges the template content with existing values.
	MergePolicyMerge TemplateMergePolicy = "Merge"
)

type TemplateRef

type TemplateRef struct {
	// The name of the ConfigMap/Secret resource
	// +kubebuilder:validation:MinLength:=1
	// +kubebuilder:validation:MaxLength:=253
	// +kubebuilder:validation:Pattern:=^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$
	Name string `json:"name"`

	// A list of keys in the ConfigMap/Secret to use as templates for Secret data
	Items []TemplateRefItem `json:"items"`
}

TemplateRef specifies a reference to either a ConfigMap or a Secret resource.

func (*TemplateRef) DeepCopy

func (in *TemplateRef) DeepCopy() *TemplateRef

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateRef.

func (*TemplateRef) DeepCopyInto

func (in *TemplateRef) DeepCopyInto(out *TemplateRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TemplateRefItem

type TemplateRefItem struct {
	// A key in the ConfigMap/Secret
	// +kubebuilder:validation:MinLength:=1
	// +kubebuilder:validation:MaxLength:=253
	// +kubebuilder:validation:Pattern:=^[-._a-zA-Z0-9]+$
	Key string `json:"key"`

	// +kubebuilder:default="Values"
	TemplateAs TemplateScope `json:"templateAs,omitempty"`
}

TemplateRefItem specifies a key in the ConfigMap/Secret to use as a template for Secret data.

func (*TemplateRefItem) DeepCopy

func (in *TemplateRefItem) DeepCopy() *TemplateRefItem

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateRefItem.

func (*TemplateRefItem) DeepCopyInto

func (in *TemplateRefItem) DeepCopyInto(out *TemplateRefItem)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TemplateScope

type TemplateScope string

TemplateScope specifies how the template keys should be interpreted. +kubebuilder:validation:Enum=Values;KeysAndValues

const (
	TemplateScopeValues        TemplateScope = "Values"
	TemplateScopeKeysAndValues TemplateScope = "KeysAndValues"
)

These are used to define the scope of templates.

type TemplateTarget

type TemplateTarget string

TemplateTarget defines the target field where the template result will be stored. +kubebuilder:validation:Enum=Data;Annotations;Labels

const (
	// TemplateTargetData stores template results in the data field of the secret.
	TemplateTargetData TemplateTarget = "Data"

	// TemplateTargetAnnotations stores template results in the annotations field of the secret.
	TemplateTargetAnnotations TemplateTarget = "Annotations"

	// TemplateTargetLabels stores template results in the labels field of the secret.
	TemplateTargetLabels TemplateTarget = "Labels"
)

Jump to