secretstore

package
v0.0.0-...-f3c1a41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

const (
	TriggerReconcileAnnotation = "ack-secret-manager.alibabacloud.com/trigger-reconcile"
	LastTriggerReconcileKey    = "ack-secret-manager.alibabacloud.com/last-trigger-reconcile"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ClusterSecretStorePredicate

type ClusterSecretStorePredicate struct{}

func (ClusterSecretStorePredicate) Create

func (ClusterSecretStorePredicate) Delete

func (ClusterSecretStorePredicate) Generic

func (ClusterSecretStorePredicate) Update

type ClusterSecretStoreReconciler

type ClusterSecretStoreReconciler struct {
	*CommonReconciler
	Client               client.Client
	Scheme               *runtime.Scheme
	Log                  logr.Logger
	Ctx                  context.Context
	ReconciliationPeriod time.Duration
}

ClusterSecretStoreReconciler reconciles a ClusterSecretStore object

func (*ClusterSecretStoreReconciler) Reconcile

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.

func (*ClusterSecretStoreReconciler) SetupWithManager

func (r *ClusterSecretStoreReconciler) SetupWithManager(mgr ctrl.Manager, reconcileCount int) error

SetupWithManager sets up the controller with the Manager.

type ClusterSecretStoreSpecWrapper

type ClusterSecretStoreSpecWrapper struct {
	*v1alpha1.ClusterSecretStoreSpec
}

ClusterSecretStoreSpecWrapper wraps ClusterSecretStoreSpec to implement StoreSpecInterface

func (*ClusterSecretStoreSpecWrapper) GetAccessKey

func (*ClusterSecretStoreSpecWrapper) GetAccessKeySecret

func (w *ClusterSecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef

func (*ClusterSecretStoreSpecWrapper) GetConditions

func (*ClusterSecretStoreSpecWrapper) GetKMS

func (*ClusterSecretStoreSpecWrapper) GetOOS

func (*ClusterSecretStoreSpecWrapper) GetServiceAccountRef

func (w *ClusterSecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef

type ClusterSecretStoreStatusWrapper

type ClusterSecretStoreStatusWrapper struct {
	*v1alpha1.ClusterSecretStoreStatus
}

ClusterSecretStoreStatusWrapper wraps ClusterSecretStoreStatus to implement StoreStatusInterface

func (*ClusterSecretStoreStatusWrapper) GetCapabilities

func (*ClusterSecretStoreStatusWrapper) GetConditions

func (*ClusterSecretStoreStatusWrapper) SetCapabilities

func (w *ClusterSecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)

func (*ClusterSecretStoreStatusWrapper) SetConditions

type ClusterSecretStoreWrapper

type ClusterSecretStoreWrapper struct {
	*v1alpha1.ClusterSecretStore
}

ClusterSecretStoreWrapper wraps ClusterSecretStore to implement StoreInterface

func (*ClusterSecretStoreWrapper) GetSpec

func (*ClusterSecretStoreWrapper) GetStatus

type CommonReconciler

type CommonReconciler struct {
	client.Client
	RestConfig                  *rest.Config
	EnableCrossNamespaceAuthRef bool
}

CommonReconciler contains common logic for both SecretStore and ClusterSecretStore controllers

type SecretStorePredicate

type SecretStorePredicate struct{}

func (SecretStorePredicate) Create

func (SecretStorePredicate) Delete

func (SecretStorePredicate) Generic

func (SecretStorePredicate) Update

type SecretStoreReconciler

type SecretStoreReconciler struct {
	*CommonReconciler
	Client               client.Client
	Scheme               *runtime.Scheme
	Log                  logr.Logger
	Ctx                  context.Context
	ReconciliationPeriod time.Duration
}

SecretStoreReconciler reconciles a SecretStore object

func (*SecretStoreReconciler) Reconcile

func (r *SecretStoreReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)

Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.

func (*SecretStoreReconciler) SetupWithManager

func (r *SecretStoreReconciler) SetupWithManager(mgr ctrl.Manager, reconcileCount int) error

SetupWithManager sets up the controller with the Manager.

type SecretStoreSpecWrapper

type SecretStoreSpecWrapper struct {
	*v1alpha1.SecretStoreSpec
}

SecretStoreSpecWrapper wraps SecretStoreSpec to implement StoreSpecInterface

func (*SecretStoreSpecWrapper) GetAccessKey

func (w *SecretStoreSpecWrapper) GetAccessKey() *v1alpha1.SecretRef

func (*SecretStoreSpecWrapper) GetAccessKeySecret

func (w *SecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef

func (*SecretStoreSpecWrapper) GetConditions

func (*SecretStoreSpecWrapper) GetKMS

func (*SecretStoreSpecWrapper) GetOOS

func (*SecretStoreSpecWrapper) GetServiceAccountRef

func (w *SecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef

type SecretStoreStatusWrapper

type SecretStoreStatusWrapper struct {
	*v1alpha1.SecretStoreStatus
}

SecretStoreStatusWrapper wraps SecretStoreStatus to implement StoreStatusInterface

func (*SecretStoreStatusWrapper) GetCapabilities

func (*SecretStoreStatusWrapper) GetConditions

func (*SecretStoreStatusWrapper) SetCapabilities

func (w *SecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)

func (*SecretStoreStatusWrapper) SetConditions

func (w *SecretStoreStatusWrapper) SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)

type SecretStoreWrapper

type SecretStoreWrapper struct {
	*v1alpha1.SecretStore
}

SecretStoreWrapper wraps SecretStore to implement StoreInterface

func (*SecretStoreWrapper) GetSpec

func (*SecretStoreWrapper) GetStatus

type StoreInterface

type StoreInterface interface {
	client.Object
	GetName() string
	GetNamespace() string
	GetSpec() StoreSpecInterface
	GetStatus() StoreStatusInterface
	GetFinalizers() []string
	SetFinalizers([]string)
	GetGeneration() int64
	GetDeletionTimestamp() *metav1.Time
}

StoreInterface defines the common interface for both SecretStore and ClusterSecretStore

type StoreSpecInterface

type StoreSpecInterface interface {
	GetKMS() *v1alpha1.KMSProvider
	GetOOS() *v1alpha1.OOSProvider
	GetConditions() []v1alpha1.ClusterSecretStoreCondition
	GetServiceAccountRef() *v1alpha1.ServiceAccountRef
	GetAccessKey() *v1alpha1.SecretRef
	GetAccessKeySecret() *v1alpha1.SecretRef
}

StoreSpecInterface defines the common interface for both SecretStoreSpec and ClusterSecretStoreSpec

type StoreStatusInterface

type StoreStatusInterface interface {
	GetConditions() []v1alpha1.SecretStoreStatusCondition
	GetCapabilities() v1alpha1.SecretStoreCapabilities
	SetCapabilities(v1alpha1.SecretStoreCapabilities)
	SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
}

StoreStatusInterface defines the common interface for both SecretStoreStatus and ClusterSecretStoreStatus

type WrappedClient

type WrappedClient struct {
	client.Client
	KubeClient kubernetes.Interface
}

WrappedClient wraps both controller-runtime client and kubernetes client

func (*WrappedClient) GetKubeClient

func (w *WrappedClient) GetKubeClient() kubernetes.Interface

GetKubeClient returns the kubernetes client interface

Jump to