Documentation
¶
Index ¶
- Constants
- type ClusterSecretStorePredicate
- type ClusterSecretStoreReconciler
- type ClusterSecretStoreSpecWrapper
- func (w *ClusterSecretStoreSpecWrapper) GetAccessKey() *v1alpha1.SecretRef
- func (w *ClusterSecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef
- func (w *ClusterSecretStoreSpecWrapper) GetConditions() []v1alpha1.ClusterSecretStoreCondition
- func (w *ClusterSecretStoreSpecWrapper) GetKMS() *v1alpha1.KMSProvider
- func (w *ClusterSecretStoreSpecWrapper) GetOOS() *v1alpha1.OOSProvider
- func (w *ClusterSecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef
- type ClusterSecretStoreStatusWrapper
- func (w *ClusterSecretStoreStatusWrapper) GetCapabilities() v1alpha1.SecretStoreCapabilities
- func (w *ClusterSecretStoreStatusWrapper) GetConditions() []v1alpha1.SecretStoreStatusCondition
- func (w *ClusterSecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)
- func (w *ClusterSecretStoreStatusWrapper) SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
- type ClusterSecretStoreWrapper
- type CommonReconciler
- type SecretStorePredicate
- type SecretStoreReconciler
- type SecretStoreSpecWrapper
- func (w *SecretStoreSpecWrapper) GetAccessKey() *v1alpha1.SecretRef
- func (w *SecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef
- func (w *SecretStoreSpecWrapper) GetConditions() []v1alpha1.ClusterSecretStoreCondition
- func (w *SecretStoreSpecWrapper) GetKMS() *v1alpha1.KMSProvider
- func (w *SecretStoreSpecWrapper) GetOOS() *v1alpha1.OOSProvider
- func (w *SecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef
- type SecretStoreStatusWrapper
- func (w *SecretStoreStatusWrapper) GetCapabilities() v1alpha1.SecretStoreCapabilities
- func (w *SecretStoreStatusWrapper) GetConditions() []v1alpha1.SecretStoreStatusCondition
- func (w *SecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)
- func (w *SecretStoreStatusWrapper) SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
- type SecretStoreWrapper
- type StoreInterface
- type StoreSpecInterface
- type StoreStatusInterface
- type WrappedClient
Constants ¶
const ( TriggerReconcileAnnotation = "ack-secret-manager.alibabacloud.com/trigger-reconcile" LastTriggerReconcileKey = "ack-secret-manager.alibabacloud.com/last-trigger-reconcile" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterSecretStorePredicate ¶
type ClusterSecretStorePredicate struct{}
func (ClusterSecretStorePredicate) Create ¶
func (p ClusterSecretStorePredicate) Create(e event.CreateEvent) bool
func (ClusterSecretStorePredicate) Delete ¶
func (p ClusterSecretStorePredicate) Delete(e event.DeleteEvent) bool
func (ClusterSecretStorePredicate) Generic ¶
func (p ClusterSecretStorePredicate) Generic(e event.GenericEvent) bool
func (ClusterSecretStorePredicate) Update ¶
func (p ClusterSecretStorePredicate) Update(e event.UpdateEvent) bool
type ClusterSecretStoreReconciler ¶
type ClusterSecretStoreReconciler struct {
*CommonReconciler
Client client.Client
Scheme *runtime.Scheme
Log logr.Logger
Ctx context.Context
ReconciliationPeriod time.Duration
}
ClusterSecretStoreReconciler reconciles a ClusterSecretStore object
func (*ClusterSecretStoreReconciler) Reconcile ¶
func (r *ClusterSecretStoreReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*ClusterSecretStoreReconciler) SetupWithManager ¶
func (r *ClusterSecretStoreReconciler) SetupWithManager(mgr ctrl.Manager, reconcileCount int) error
SetupWithManager sets up the controller with the Manager.
type ClusterSecretStoreSpecWrapper ¶
type ClusterSecretStoreSpecWrapper struct {
*v1alpha1.ClusterSecretStoreSpec
}
ClusterSecretStoreSpecWrapper wraps ClusterSecretStoreSpec to implement StoreSpecInterface
func (*ClusterSecretStoreSpecWrapper) GetAccessKey ¶
func (w *ClusterSecretStoreSpecWrapper) GetAccessKey() *v1alpha1.SecretRef
func (*ClusterSecretStoreSpecWrapper) GetAccessKeySecret ¶
func (w *ClusterSecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef
func (*ClusterSecretStoreSpecWrapper) GetConditions ¶
func (w *ClusterSecretStoreSpecWrapper) GetConditions() []v1alpha1.ClusterSecretStoreCondition
func (*ClusterSecretStoreSpecWrapper) GetKMS ¶
func (w *ClusterSecretStoreSpecWrapper) GetKMS() *v1alpha1.KMSProvider
func (*ClusterSecretStoreSpecWrapper) GetOOS ¶
func (w *ClusterSecretStoreSpecWrapper) GetOOS() *v1alpha1.OOSProvider
func (*ClusterSecretStoreSpecWrapper) GetServiceAccountRef ¶
func (w *ClusterSecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef
type ClusterSecretStoreStatusWrapper ¶
type ClusterSecretStoreStatusWrapper struct {
*v1alpha1.ClusterSecretStoreStatus
}
ClusterSecretStoreStatusWrapper wraps ClusterSecretStoreStatus to implement StoreStatusInterface
func (*ClusterSecretStoreStatusWrapper) GetCapabilities ¶
func (w *ClusterSecretStoreStatusWrapper) GetCapabilities() v1alpha1.SecretStoreCapabilities
func (*ClusterSecretStoreStatusWrapper) GetConditions ¶
func (w *ClusterSecretStoreStatusWrapper) GetConditions() []v1alpha1.SecretStoreStatusCondition
func (*ClusterSecretStoreStatusWrapper) SetCapabilities ¶
func (w *ClusterSecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)
func (*ClusterSecretStoreStatusWrapper) SetConditions ¶
func (w *ClusterSecretStoreStatusWrapper) SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
type ClusterSecretStoreWrapper ¶
type ClusterSecretStoreWrapper struct {
*v1alpha1.ClusterSecretStore
}
ClusterSecretStoreWrapper wraps ClusterSecretStore to implement StoreInterface
func (*ClusterSecretStoreWrapper) GetSpec ¶
func (w *ClusterSecretStoreWrapper) GetSpec() StoreSpecInterface
func (*ClusterSecretStoreWrapper) GetStatus ¶
func (w *ClusterSecretStoreWrapper) GetStatus() StoreStatusInterface
type CommonReconciler ¶
type CommonReconciler struct {
client.Client
RestConfig *rest.Config
EnableCrossNamespaceAuthRef bool
}
CommonReconciler contains common logic for both SecretStore and ClusterSecretStore controllers
type SecretStorePredicate ¶
type SecretStorePredicate struct{}
func (SecretStorePredicate) Create ¶
func (p SecretStorePredicate) Create(e event.CreateEvent) bool
func (SecretStorePredicate) Delete ¶
func (p SecretStorePredicate) Delete(e event.DeleteEvent) bool
func (SecretStorePredicate) Generic ¶
func (p SecretStorePredicate) Generic(e event.GenericEvent) bool
func (SecretStorePredicate) Update ¶
func (p SecretStorePredicate) Update(e event.UpdateEvent) bool
type SecretStoreReconciler ¶
type SecretStoreReconciler struct {
*CommonReconciler
Client client.Client
Scheme *runtime.Scheme
Log logr.Logger
Ctx context.Context
ReconciliationPeriod time.Duration
}
SecretStoreReconciler reconciles a SecretStore object
func (*SecretStoreReconciler) Reconcile ¶
func (r *SecretStoreReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*SecretStoreReconciler) SetupWithManager ¶
func (r *SecretStoreReconciler) SetupWithManager(mgr ctrl.Manager, reconcileCount int) error
SetupWithManager sets up the controller with the Manager.
type SecretStoreSpecWrapper ¶
type SecretStoreSpecWrapper struct {
*v1alpha1.SecretStoreSpec
}
SecretStoreSpecWrapper wraps SecretStoreSpec to implement StoreSpecInterface
func (*SecretStoreSpecWrapper) GetAccessKey ¶
func (w *SecretStoreSpecWrapper) GetAccessKey() *v1alpha1.SecretRef
func (*SecretStoreSpecWrapper) GetAccessKeySecret ¶
func (w *SecretStoreSpecWrapper) GetAccessKeySecret() *v1alpha1.SecretRef
func (*SecretStoreSpecWrapper) GetConditions ¶
func (w *SecretStoreSpecWrapper) GetConditions() []v1alpha1.ClusterSecretStoreCondition
func (*SecretStoreSpecWrapper) GetKMS ¶
func (w *SecretStoreSpecWrapper) GetKMS() *v1alpha1.KMSProvider
func (*SecretStoreSpecWrapper) GetOOS ¶
func (w *SecretStoreSpecWrapper) GetOOS() *v1alpha1.OOSProvider
func (*SecretStoreSpecWrapper) GetServiceAccountRef ¶
func (w *SecretStoreSpecWrapper) GetServiceAccountRef() *v1alpha1.ServiceAccountRef
type SecretStoreStatusWrapper ¶
type SecretStoreStatusWrapper struct {
*v1alpha1.SecretStoreStatus
}
SecretStoreStatusWrapper wraps SecretStoreStatus to implement StoreStatusInterface
func (*SecretStoreStatusWrapper) GetCapabilities ¶
func (w *SecretStoreStatusWrapper) GetCapabilities() v1alpha1.SecretStoreCapabilities
func (*SecretStoreStatusWrapper) GetConditions ¶
func (w *SecretStoreStatusWrapper) GetConditions() []v1alpha1.SecretStoreStatusCondition
func (*SecretStoreStatusWrapper) SetCapabilities ¶
func (w *SecretStoreStatusWrapper) SetCapabilities(capabilities v1alpha1.SecretStoreCapabilities)
func (*SecretStoreStatusWrapper) SetConditions ¶
func (w *SecretStoreStatusWrapper) SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
type SecretStoreWrapper ¶
type SecretStoreWrapper struct {
*v1alpha1.SecretStore
}
SecretStoreWrapper wraps SecretStore to implement StoreInterface
func (*SecretStoreWrapper) GetSpec ¶
func (w *SecretStoreWrapper) GetSpec() StoreSpecInterface
func (*SecretStoreWrapper) GetStatus ¶
func (w *SecretStoreWrapper) GetStatus() StoreStatusInterface
type StoreInterface ¶
type StoreInterface interface {
client.Object
GetName() string
GetNamespace() string
GetSpec() StoreSpecInterface
GetStatus() StoreStatusInterface
GetFinalizers() []string
SetFinalizers([]string)
GetGeneration() int64
GetDeletionTimestamp() *metav1.Time
}
StoreInterface defines the common interface for both SecretStore and ClusterSecretStore
type StoreSpecInterface ¶
type StoreSpecInterface interface {
GetKMS() *v1alpha1.KMSProvider
GetOOS() *v1alpha1.OOSProvider
GetConditions() []v1alpha1.ClusterSecretStoreCondition
GetServiceAccountRef() *v1alpha1.ServiceAccountRef
GetAccessKey() *v1alpha1.SecretRef
GetAccessKeySecret() *v1alpha1.SecretRef
}
StoreSpecInterface defines the common interface for both SecretStoreSpec and ClusterSecretStoreSpec
type StoreStatusInterface ¶
type StoreStatusInterface interface {
GetConditions() []v1alpha1.SecretStoreStatusCondition
GetCapabilities() v1alpha1.SecretStoreCapabilities
SetCapabilities(v1alpha1.SecretStoreCapabilities)
SetConditions(conditions []v1alpha1.SecretStoreStatusCondition)
}
StoreStatusInterface defines the common interface for both SecretStoreStatus and ClusterSecretStoreStatus
type WrappedClient ¶
type WrappedClient struct {
client.Client
KubeClient kubernetes.Interface
}
WrappedClient wraps both controller-runtime client and kubernetes client
func (*WrappedClient) GetKubeClient ¶
func (w *WrappedClient) GetKubeClient() kubernetes.Interface
GetKubeClient returns the kubernetes client interface